# Docker Engine API Client

This library is automatically generated by [openapi-generator](https://github.com/OpenAPITools/openapi-generator),
based on the specification that can be downloaded from [this page](https://docs.docker.com/engine/api/v1.40/),
with various handcoded fixes and improvements.

> Use this library at your own risk. It was automatically generated, and I did not write unit tests for it.

The default base URL used for the docker engine is `http://localhost:2375/v1.40`. You can explicitly initialize the `ApiClient` class with another `basePath`.

> The docker engine normally listens on a unix domain socket. Due to dart's lack of support for HTTP over unix sockets,
> this library uses HTTP over TCP. This being so, you need to set your docker engine to listen on TCP.

# Docker Engine API
The Engine API is an HTTP API served by Docker Engine. It is the API the
Docker client uses to communicate with the Engine, so everything the Docker
client can do can be done with the API.

Most of the client's commands map directly to API endpoints (e.g. `docker ps`
is `GET /containers/json`). The notable exception is running containers,
which consists of several API calls.

# Errors

The API uses standard HTTP status codes to indicate the success or failure
of the API call. The body of the response will be JSON in the following
format:

```
{
  \"message\": \"page not found\"
}
```

# Versioning

The API is usually changed in each release, so API calls are versioned to
ensure that clients don't break. To lock to a specific version of the API,
you prefix the URL with its version, for example, call `/v1.30/info` to use
the v1.30 version of the `/info` endpoint. If the API version specified in
the URL is not supported by the daemon, a HTTP `400 Bad Request` error message
is returned.

If you omit the version-prefix, the current version of the API (v1.40) is used.
For example, calling `/info` is the same as calling `/v1.40/info`. Using the
API without a version-prefix is deprecated and will be removed in a future release.

Engine releases in the near future should support this version of the API,
so your client will continue to work even if it is talking to a newer Engine.

The API uses an open schema model, which means server may add extra properties
to responses. Likewise, the server will ignore any extra query parameters and
request body properties. When you write clients, you need to ignore additional
properties in responses to ensure they do not break when talking to newer
daemons.


# Authentication

Authentication for registries is handled client side. The client has to send
authentication details to various endpoints that need to communicate with
registries, such as `POST /images/(name)/push`. These are sent as
`X-Registry-Auth` header as a [base64url encoded](https://tools.ietf.org/html/rfc4648#section-5)
(JSON) string with the following structure:

```
{
  \"username\": \"string\",
  \"password\": \"string\",
  \"email\": \"string\",
  \"serveraddress\": \"string\"
}
```

The `serveraddress` is a domain/IP without a protocol. Throughout this
structure, double quotes are required.

If you have already got an identity token from the [`/auth` endpoint](#operation/SystemAuth),
you can just pass this instead of credentials:

```
{
  \"identitytoken\": \"9cbaf023786cd7...\"
}
```


This Dart package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.40
- Build package: org.openapitools.codegen.languages.DartClientCodegen

## Requirements

Dart 2.0 or later

## Installation & Usage

### Github
If this Dart package is published to Github, add the following dependency to your pubspec.yaml
```
dependencies:
  openapi:
    git: https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```

### Local
To use the package in your local drive, add the following dependency to your pubspec.yaml
```
dependencies:
  openapi:
    path: /path/to/openapi
```

## Tests

TODO

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```dart
import 'package:docker_client/api.dart';


var api_instance = ConfigApi();
var body = ConfigSpec(); // Object |

try {
    var result = api_instance.configCreate(body);
    print(result);
} catch (e) {
    print("Exception when calling ConfigApi->configCreate: $e\n");
}

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost/v1.40*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ConfigApi* | [**configCreate**](doc\/ConfigApi.md#configcreate) | **POST** /configs/create | Create a config
*ConfigApi* | [**configDelete**](doc\/ConfigApi.md#configdelete) | **DELETE** /configs/{id} | Delete a config
*ConfigApi* | [**configInspect**](doc\/ConfigApi.md#configinspect) | **GET** /configs/{id} | Inspect a config
*ConfigApi* | [**configList**](doc\/ConfigApi.md#configlist) | **GET** /configs | List configs
*ConfigApi* | [**configUpdate**](doc\/ConfigApi.md#configupdate) | **POST** /configs/{id}/update | Update a Config
*ContainerApi* | [**containerArchive**](doc\/ContainerApi.md#containerarchive) | **GET** /containers/{id}/archive | Get an archive of a filesystem resource in a container
*ContainerApi* | [**containerArchiveInfo**](doc\/ContainerApi.md#containerarchiveinfo) | **HEAD** /containers/{id}/archive | Get information about files in a container
*ContainerApi* | [**containerAttach**](doc\/ContainerApi.md#containerattach) | **POST** /containers/{id}/attach | Attach to a container
*ContainerApi* | [**containerAttachWebsocket**](doc\/ContainerApi.md#containerattachwebsocket) | **GET** /containers/{id}/attach/ws | Attach to a container via a websocket
*ContainerApi* | [**containerChanges**](doc\/ContainerApi.md#containerchanges) | **GET** /containers/{id}/changes | Get changes on a container’s filesystem
*ContainerApi* | [**containerCreate**](doc\/ContainerApi.md#containercreate) | **POST** /containers/create | Create a container
*ContainerApi* | [**containerDelete**](doc\/ContainerApi.md#containerdelete) | **DELETE** /containers/{id} | Remove a container
*ContainerApi* | [**containerExport**](doc\/ContainerApi.md#containerexport) | **GET** /containers/{id}/export | Export a container
*ContainerApi* | [**containerInspect**](doc\/ContainerApi.md#containerinspect) | **GET** /containers/{id}/json | Inspect a container
*ContainerApi* | [**containerKill**](doc\/ContainerApi.md#containerkill) | **POST** /containers/{id}/kill | Kill a container
*ContainerApi* | [**containerList**](doc\/ContainerApi.md#containerlist) | **GET** /containers/json | List containers
*ContainerApi* | [**containerLogs**](doc\/ContainerApi.md#containerlogs) | **GET** /containers/{id}/logs | Get container logs
*ContainerApi* | [**containerPause**](doc\/ContainerApi.md#containerpause) | **POST** /containers/{id}/pause | Pause a container
*ContainerApi* | [**containerPrune**](doc\/ContainerApi.md#containerprune) | **POST** /containers/prune | Delete stopped containers
*ContainerApi* | [**containerRename**](doc\/ContainerApi.md#containerrename) | **POST** /containers/{id}/rename | Rename a container
*ContainerApi* | [**containerResize**](doc\/ContainerApi.md#containerresize) | **POST** /containers/{id}/resize | Resize a container TTY
*ContainerApi* | [**containerRestart**](doc\/ContainerApi.md#containerrestart) | **POST** /containers/{id}/restart | Restart a container
*ContainerApi* | [**containerStart**](doc\/ContainerApi.md#containerstart) | **POST** /containers/{id}/start | Start a container
*ContainerApi* | [**containerStats**](doc\/ContainerApi.md#containerstats) | **GET** /containers/{id}/stats | Get container stats based on resource usage
*ContainerApi* | [**containerStop**](doc\/ContainerApi.md#containerstop) | **POST** /containers/{id}/stop | Stop a container
*ContainerApi* | [**containerTop**](doc\/ContainerApi.md#containertop) | **GET** /containers/{id}/top | List processes running inside a container
*ContainerApi* | [**containerUnpause**](doc\/ContainerApi.md#containerunpause) | **POST** /containers/{id}/unpause | Unpause a container
*ContainerApi* | [**containerUpdate**](doc\/ContainerApi.md#containerupdate) | **POST** /containers/{id}/update | Update a container
*ContainerApi* | [**containerWait**](doc\/ContainerApi.md#containerwait) | **POST** /containers/{id}/wait | Wait for a container
*ContainerApi* | [**putContainerArchive**](doc\/ContainerApi.md#putcontainerarchive) | **PUT** /containers/{id}/archive | Extract an archive of files or folders to a directory in a container
*DistributionApi* | [**distributionInspect**](doc\/DistributionApi.md#distributioninspect) | **GET** /distribution/{name}/json | Get image information from the registry
*ExecApi* | [**containerExec**](doc\/ExecApi.md#containerexec) | **POST** /containers/{id}/exec | Create an exec instance
*ExecApi* | [**execInspect**](doc\/ExecApi.md#execinspect) | **GET** /exec/{id}/json | Inspect an exec instance
*ExecApi* | [**execResize**](doc\/ExecApi.md#execresize) | **POST** /exec/{id}/resize | Resize an exec instance
*ExecApi* | [**execStart**](doc\/ExecApi.md#execstart) | **POST** /exec/{id}/start | Start an exec instance
*ImageApi* | [**buildPrune**](doc\/ImageApi.md#buildprune) | **POST** /build/prune | Delete builder cache
*ImageApi* | [**imageBuild**](doc\/ImageApi.md#imagebuild) | **POST** /build | Build an image
*ImageApi* | [**imageCommit**](doc\/ImageApi.md#imagecommit) | **POST** /commit | Create a new image from a container
*ImageApi* | [**imageCreate**](doc\/ImageApi.md#imagecreate) | **POST** /images/create | Create an image
*ImageApi* | [**imageDelete**](doc\/ImageApi.md#imagedelete) | **DELETE** /images/{name} | Remove an image
*ImageApi* | [**imageGet**](doc\/ImageApi.md#imageget) | **GET** /images/{name}/get | Export an image
*ImageApi* | [**imageGetAll**](doc\/ImageApi.md#imagegetall) | **GET** /images/get | Export several images
*ImageApi* | [**imageHistory**](doc\/ImageApi.md#imagehistory) | **GET** /images/{name}/history | Get the history of an image
*ImageApi* | [**imageInspect**](doc\/ImageApi.md#imageinspect) | **GET** /images/{name}/json | Inspect an image
*ImageApi* | [**imageList**](doc\/ImageApi.md#imagelist) | **GET** /images/json | List Images
*ImageApi* | [**imageLoad**](doc\/ImageApi.md#imageload) | **POST** /images/load | Import images
*ImageApi* | [**imagePrune**](doc\/ImageApi.md#imageprune) | **POST** /images/prune | Delete unused images
*ImageApi* | [**imagePush**](doc\/ImageApi.md#imagepush) | **POST** /images/{name}/push | Push an image
*ImageApi* | [**imageSearch**](doc\/ImageApi.md#imagesearch) | **GET** /images/search | Search images
*ImageApi* | [**imageTag**](doc\/ImageApi.md#imagetag) | **POST** /images/{name}/tag | Tag an image
*NetworkApi* | [**networkConnect**](doc\/NetworkApi.md#networkconnect) | **POST** /networks/{id}/connect | Connect a container to a network
*NetworkApi* | [**networkCreate**](doc\/NetworkApi.md#networkcreate) | **POST** /networks/create | Create a network
*NetworkApi* | [**networkDelete**](doc\/NetworkApi.md#networkdelete) | **DELETE** /networks/{id} | Remove a network
*NetworkApi* | [**networkDisconnect**](doc\/NetworkApi.md#networkdisconnect) | **POST** /networks/{id}/disconnect | Disconnect a container from a network
*NetworkApi* | [**networkInspect**](doc\/NetworkApi.md#networkinspect) | **GET** /networks/{id} | Inspect a network
*NetworkApi* | [**networkList**](doc\/NetworkApi.md#networklist) | **GET** /networks | List networks
*NetworkApi* | [**networkPrune**](doc\/NetworkApi.md#networkprune) | **POST** /networks/prune | Delete unused networks
*NodeApi* | [**nodeDelete**](doc\/NodeApi.md#nodedelete) | **DELETE** /nodes/{id} | Delete a node
*NodeApi* | [**nodeInspect**](doc\/NodeApi.md#nodeinspect) | **GET** /nodes/{id} | Inspect a node
*NodeApi* | [**nodeList**](doc\/NodeApi.md#nodelist) | **GET** /nodes | List nodes
*NodeApi* | [**nodeUpdate**](doc\/NodeApi.md#nodeupdate) | **POST** /nodes/{id}/update | Update a node
*PluginApi* | [**getPluginPrivileges**](doc\/PluginApi.md#getpluginprivileges) | **GET** /plugins/privileges | Get plugin privileges
*PluginApi* | [**pluginCreate**](doc\/PluginApi.md#plugincreate) | **POST** /plugins/create | Create a plugin
*PluginApi* | [**pluginDelete**](doc\/PluginApi.md#plugindelete) | **DELETE** /plugins/{name} | Remove a plugin
*PluginApi* | [**pluginDisable**](doc\/PluginApi.md#plugindisable) | **POST** /plugins/{name}/disable | Disable a plugin
*PluginApi* | [**pluginEnable**](doc\/PluginApi.md#pluginenable) | **POST** /plugins/{name}/enable | Enable a plugin
*PluginApi* | [**pluginInspect**](doc\/PluginApi.md#plugininspect) | **GET** /plugins/{name}/json | Inspect a plugin
*PluginApi* | [**pluginList**](doc\/PluginApi.md#pluginlist) | **GET** /plugins | List plugins
*PluginApi* | [**pluginPull**](doc\/PluginApi.md#pluginpull) | **POST** /plugins/pull | Install a plugin
*PluginApi* | [**pluginPush**](doc\/PluginApi.md#pluginpush) | **POST** /plugins/{name}/push | Push a plugin
*PluginApi* | [**pluginSet**](doc\/PluginApi.md#pluginset) | **POST** /plugins/{name}/set | Configure a plugin
*PluginApi* | [**pluginUpgrade**](doc\/PluginApi.md#pluginupgrade) | **POST** /plugins/{name}/upgrade | Upgrade a plugin
*SecretApi* | [**secretCreate**](doc\/SecretApi.md#secretcreate) | **POST** /secrets/create | Create a secret
*SecretApi* | [**secretDelete**](doc\/SecretApi.md#secretdelete) | **DELETE** /secrets/{id} | Delete a secret
*SecretApi* | [**secretInspect**](doc\/SecretApi.md#secretinspect) | **GET** /secrets/{id} | Inspect a secret
*SecretApi* | [**secretList**](doc\/SecretApi.md#secretlist) | **GET** /secrets | List secrets
*SecretApi* | [**secretUpdate**](doc\/SecretApi.md#secretupdate) | **POST** /secrets/{id}/update | Update a Secret
*ServiceApi* | [**serviceCreate**](doc\/ServiceApi.md#servicecreate) | **POST** /services/create | Create a service
*ServiceApi* | [**serviceDelete**](doc\/ServiceApi.md#servicedelete) | **DELETE** /services/{id} | Delete a service
*ServiceApi* | [**serviceInspect**](doc\/ServiceApi.md#serviceinspect) | **GET** /services/{id} | Inspect a service
*ServiceApi* | [**serviceList**](doc\/ServiceApi.md#servicelist) | **GET** /services | List services
*ServiceApi* | [**serviceLogs**](doc\/ServiceApi.md#servicelogs) | **GET** /services/{id}/logs | Get service logs
*ServiceApi* | [**serviceUpdate**](doc\/ServiceApi.md#serviceupdate) | **POST** /services/{id}/update | Update a service
*SessionApi* | [**session**](doc\/SessionApi.md#session) | **POST** /session | Initialize interactive session
*SwarmApi* | [**swarmInit**](doc\/SwarmApi.md#swarminit) | **POST** /swarm/init | Initialize a new swarm
*SwarmApi* | [**swarmInspect**](doc\/SwarmApi.md#swarminspect) | **GET** /swarm | Inspect swarm
*SwarmApi* | [**swarmJoin**](doc\/SwarmApi.md#swarmjoin) | **POST** /swarm/join | Join an existing swarm
*SwarmApi* | [**swarmLeave**](doc\/SwarmApi.md#swarmleave) | **POST** /swarm/leave | Leave a swarm
*SwarmApi* | [**swarmUnlock**](doc\/SwarmApi.md#swarmunlock) | **POST** /swarm/unlock | Unlock a locked manager
*SwarmApi* | [**swarmUnlockkey**](doc\/SwarmApi.md#swarmunlockkey) | **GET** /swarm/unlockkey | Get the unlock key
*SwarmApi* | [**swarmUpdate**](doc\/SwarmApi.md#swarmupdate) | **POST** /swarm/update | Update a swarm
*SystemApi* | [**systemAuth**](doc\/SystemApi.md#systemauth) | **POST** /auth | Check auth configuration
*SystemApi* | [**systemDataUsage**](doc\/SystemApi.md#systemdatausage) | **GET** /system/df | Get data usage information
*SystemApi* | [**systemEvents**](doc\/SystemApi.md#systemevents) | **GET** /events | Monitor events
*SystemApi* | [**systemInfo**](doc\/SystemApi.md#systeminfo) | **GET** /info | Get system information
*SystemApi* | [**systemPing**](doc\/SystemApi.md#systemping) | **GET** /_ping | Ping
*SystemApi* | [**systemPingHead**](doc\/SystemApi.md#systempinghead) | **HEAD** /_ping | Ping
*SystemApi* | [**systemVersion**](doc\/SystemApi.md#systemversion) | **GET** /version | Get version
*TaskApi* | [**taskInspect**](doc\/TaskApi.md#taskinspect) | **GET** /tasks/{id} | Inspect a task
*TaskApi* | [**taskList**](doc\/TaskApi.md#tasklist) | **GET** /tasks | List tasks
*TaskApi* | [**taskLogs**](doc\/TaskApi.md#tasklogs) | **GET** /tasks/{id}/logs | Get task logs
*VolumeApi* | [**volumeCreate**](doc\/VolumeApi.md#volumecreate) | **POST** /volumes/create | Create a volume
*VolumeApi* | [**volumeDelete**](doc\/VolumeApi.md#volumedelete) | **DELETE** /volumes/{name} | Remove a volume
*VolumeApi* | [**volumeInspect**](doc\/VolumeApi.md#volumeinspect) | **GET** /volumes/{name} | Inspect a volume
*VolumeApi* | [**volumeList**](doc\/VolumeApi.md#volumelist) | **GET** /volumes | List volumes
*VolumeApi* | [**volumePrune**](doc\/VolumeApi.md#volumeprune) | **POST** /volumes/prune | Delete unused volumes


## Documentation For Models

 - [Address](doc\/Address.md)
 - [AuthConfig](doc\/AuthConfig.md)
 - [BuildCache](doc\/BuildCache.md)
 - [BuildInfo](doc\/BuildInfo.md)
 - [BuildPruneResponse](doc\/BuildPruneResponse.md)
 - [ClusterInfo](doc\/ClusterInfo.md)
 - [Commit](doc\/Commit.md)
 - [Config](doc\/Config.md)
 - [ConfigSpec](doc\/ConfigSpec.md)
 - [ContainerChangeResponseItem](doc\/ContainerChangeResponseItem.md)
 - [ContainerConfig](doc\/ContainerConfig.md)
 - [ContainerCreateResponse](doc\/ContainerCreateResponse.md)
 - [ContainerInspectResponse](doc\/ContainerInspectResponse.md)
 - [ContainerPruneResponse](doc\/ContainerPruneResponse.md)
 - [ContainerState](doc\/ContainerState.md)
 - [ContainerTopResponse](doc\/ContainerTopResponse.md)
 - [ContainerUpdateResponse](doc\/ContainerUpdateResponse.md)
 - [ContainerWaitResponse](doc\/ContainerWaitResponse.md)
 - [ContainerWaitResponseError](doc\/ContainerWaitResponseError.md)
 - [CreateImageInfo](doc\/CreateImageInfo.md)
 - [DeviceMapping](doc\/DeviceMapping.md)
 - [DeviceRequest](doc\/DeviceRequest.md)
 - [DistributionInspectResponse](doc\/DistributionInspectResponse.md)
 - [DistributionInspectResponseDescriptor](doc\/DistributionInspectResponseDescriptor.md)
 - [DistributionInspectResponsePlatforms](doc\/DistributionInspectResponsePlatforms.md)
 - [Driver](doc\/Driver.md)
 - [EndpointIPAMConfig](doc\/EndpointIPAMConfig.md)
 - [EndpointPortConfig](doc\/EndpointPortConfig.md)
 - [EndpointSettings](doc\/EndpointSettings.md)
 - [EndpointSpec](doc\/EndpointSpec.md)
 - [EngineDescription](doc\/EngineDescription.md)
 - [EngineDescriptionPlugins](doc\/EngineDescriptionPlugins.md)
 - [ErrorDetail](doc\/ErrorDetail.md)
 - [ErrorResponse](doc\/ErrorResponse.md)
 - [ExecInspectResponse](doc\/ExecInspectResponse.md)
 - [GraphDriverData](doc\/GraphDriverData.md)
 - [Health](doc\/Health.md)
 - [HealthConfig](doc\/HealthConfig.md)
 - [HealthcheckResult](doc\/HealthcheckResult.md)
 - [HistoryResponseItem](doc\/HistoryResponseItem.md)
 - [HostConfig](doc\/HostConfig.md)
 - [HostConfigAllOf](doc\/HostConfigAllOf.md)
 - [HostConfigAllOfLogConfig](doc\/HostConfigAllOfLogConfig.md)
 - [IPAM](doc\/IPAM.md)
 - [IdResponse](doc\/IdResponse.md)
 - [Image](doc\/Image.md)
 - [ImageDeleteResponseItem](doc\/ImageDeleteResponseItem.md)
 - [ImageID](doc\/ImageID.md)
 - [ImageMetadata](doc\/ImageMetadata.md)
 - [ImagePruneResponse](doc\/ImagePruneResponse.md)
 - [ImageRootFS](doc\/ImageRootFS.md)
 - [ImageSearchResponseItem](doc\/ImageSearchResponseItem.md)
 - [ImageSummary](doc\/ImageSummary.md)
 - [IndexInfo](doc\/IndexInfo.md)
 - [InlineObject](doc\/InlineObject.md)
 - [InlineObject1](doc\/InlineObject1.md)
 - [InlineObject2](doc\/InlineObject2.md)
 - [InlineObject3](doc\/InlineObject3.md)
 - [InlineObject4](doc\/InlineObject4.md)
 - [InlineObject5](doc\/InlineObject5.md)
 - [InlineObject6](doc\/InlineObject6.md)
 - [InlineObject7](doc\/InlineObject7.md)
 - [InlineResponse400](doc\/InlineResponse400.md)
 - [JoinTokens](doc\/JoinTokens.md)
 - [LocalNodeState](doc\/LocalNodeState.md)
 - [ManagerStatus](doc\/ManagerStatus.md)
 - [Mount](doc\/Mount.md)
 - [MountBindOptions](doc\/MountBindOptions.md)
 - [MountPoint](doc\/MountPoint.md)
 - [MountTmpfsOptions](doc\/MountTmpfsOptions.md)
 - [MountVolumeOptions](doc\/MountVolumeOptions.md)
 - [MountVolumeOptionsDriverConfig](doc\/MountVolumeOptionsDriverConfig.md)
 - [Network](doc\/Network.md)
 - [NetworkAttachmentConfig](doc\/NetworkAttachmentConfig.md)
 - [NetworkContainer](doc\/NetworkContainer.md)
 - [NetworkCreateResponse](doc\/NetworkCreateResponse.md)
 - [NetworkPruneResponse](doc\/NetworkPruneResponse.md)
 - [NetworkSettings](doc\/NetworkSettings.md)
 - [NetworkingConfig](doc\/NetworkingConfig.md)
 - [Node](doc\/Node.md)
 - [NodeDescription](doc\/NodeDescription.md)
 - [NodeSpec](doc\/NodeSpec.md)
 - [NodeState](doc\/NodeState.md)
 - [NodeStatus](doc\/NodeStatus.md)
 - [ObjectVersion](doc\/ObjectVersion.md)
 - [PeerNode](doc\/PeerNode.md)
 - [Platform](doc\/Platform.md)
 - [Plugin](doc\/Plugin.md)
 - [PluginConfig](doc\/PluginConfig.md)
 - [PluginConfigArgs](doc\/PluginConfigArgs.md)
 - [PluginConfigInterface](doc\/PluginConfigInterface.md)
 - [PluginConfigLinux](doc\/PluginConfigLinux.md)
 - [PluginConfigNetwork](doc\/PluginConfigNetwork.md)
 - [PluginConfigRootfs](doc\/PluginConfigRootfs.md)
 - [PluginConfigUser](doc\/PluginConfigUser.md)
 - [PluginDevice](doc\/PluginDevice.md)
 - [PluginEnv](doc\/PluginEnv.md)
 - [PluginInterfaceType](doc\/PluginInterfaceType.md)
 - [PluginMount](doc\/PluginMount.md)
 - [PluginPrivilegeItem](doc\/PluginPrivilegeItem.md)
 - [PluginSettings](doc\/PluginSettings.md)
 - [PluginsInfo](doc\/PluginsInfo.md)
 - [Port](doc\/Port.md)
 - [PortBinding](doc\/PortBinding.md)
 - [ProcessConfig](doc\/ProcessConfig.md)
 - [ProgressDetail](doc\/ProgressDetail.md)
 - [PushImageInfo](doc\/PushImageInfo.md)
 - [Reachability](doc\/Reachability.md)
 - [RegistryServiceConfig](doc\/RegistryServiceConfig.md)
 - [ResourceObject](doc\/ResourceObject.md)
 - [Resources](doc\/Resources.md)
 - [ResourcesBlkioWeightDevice](doc\/ResourcesBlkioWeightDevice.md)
 - [ResourcesUlimits](doc\/ResourcesUlimits.md)
 - [RestartPolicy](doc\/RestartPolicy.md)
 - [Runtime](doc\/Runtime.md)
 - [Secret](doc\/Secret.md)
 - [SecretSpec](doc\/SecretSpec.md)
 - [Service](doc\/Service.md)
 - [ServiceCreateResponse](doc\/ServiceCreateResponse.md)
 - [ServiceEndpoint](doc\/ServiceEndpoint.md)
 - [ServiceEndpointVirtualIPs](doc\/ServiceEndpointVirtualIPs.md)
 - [ServiceSpec](doc\/ServiceSpec.md)
 - [ServiceSpecMode](doc\/ServiceSpecMode.md)
 - [ServiceSpecModeReplicated](doc\/ServiceSpecModeReplicated.md)
 - [ServiceSpecRollbackConfig](doc\/ServiceSpecRollbackConfig.md)
 - [ServiceSpecUpdateConfig](doc\/ServiceSpecUpdateConfig.md)
 - [ServiceUpdateResponse](doc\/ServiceUpdateResponse.md)
 - [ServiceUpdateStatus](doc\/ServiceUpdateStatus.md)
 - [Swarm](doc\/Swarm.md)
 - [SwarmAllOf](doc\/SwarmAllOf.md)
 - [SwarmInfo](doc\/SwarmInfo.md)
 - [SwarmSpec](doc\/SwarmSpec.md)
 - [SwarmSpecCAConfig](doc\/SwarmSpecCAConfig.md)
 - [SwarmSpecCAConfigExternalCAs](doc\/SwarmSpecCAConfigExternalCAs.md)
 - [SwarmSpecDispatcher](doc\/SwarmSpecDispatcher.md)
 - [SwarmSpecEncryptionConfig](doc\/SwarmSpecEncryptionConfig.md)
 - [SwarmSpecOrchestration](doc\/SwarmSpecOrchestration.md)
 - [SwarmSpecRaft](doc\/SwarmSpecRaft.md)
 - [SwarmSpecTaskDefaults](doc\/SwarmSpecTaskDefaults.md)
 - [SwarmSpecTaskDefaultsLogDriver](doc\/SwarmSpecTaskDefaultsLogDriver.md)
 - [SystemAuthResponse](doc\/SystemAuthResponse.md)
 - [SystemDataUsageResponse](doc\/SystemDataUsageResponse.md)
 - [SystemEventsResponse](doc\/SystemEventsResponse.md)
 - [SystemEventsResponseActor](doc\/SystemEventsResponseActor.md)
 - [SystemInfo](doc\/SystemInfo.md)
 - [SystemVersion](doc\/SystemVersion.md)
 - [SystemVersionComponents](doc\/SystemVersionComponents.md)
 - [SystemVersionPlatform](doc\/SystemVersionPlatform.md)
 - [TLSInfo](doc\/TLSInfo.md)
 - [Task](doc\/Task.md)
 - [TaskSpec](doc\/TaskSpec.md)
 - [TaskSpecContainerSpec](doc\/TaskSpecContainerSpec.md)
 - [TaskSpecContainerSpecConfigs](doc\/TaskSpecContainerSpecConfigs.md)
 - [TaskSpecContainerSpecDNSConfig](doc\/TaskSpecContainerSpecDNSConfig.md)
 - [TaskSpecContainerSpecFile](doc\/TaskSpecContainerSpecFile.md)
 - [TaskSpecContainerSpecFile1](doc\/TaskSpecContainerSpecFile1.md)
 - [TaskSpecContainerSpecPrivileges](doc\/TaskSpecContainerSpecPrivileges.md)
 - [TaskSpecContainerSpecPrivilegesCredentialSpec](doc\/TaskSpecContainerSpecPrivilegesCredentialSpec.md)
 - [TaskSpecContainerSpecPrivilegesSELinuxContext](doc\/TaskSpecContainerSpecPrivilegesSELinuxContext.md)
 - [TaskSpecContainerSpecSecrets](doc\/TaskSpecContainerSpecSecrets.md)
 - [TaskSpecLogDriver](doc\/TaskSpecLogDriver.md)
 - [TaskSpecNetworkAttachmentSpec](doc\/TaskSpecNetworkAttachmentSpec.md)
 - [TaskSpecPlacement](doc\/TaskSpecPlacement.md)
 - [TaskSpecPlacementPreferences](doc\/TaskSpecPlacementPreferences.md)
 - [TaskSpecPlacementSpread](doc\/TaskSpecPlacementSpread.md)
 - [TaskSpecPluginSpec](doc\/TaskSpecPluginSpec.md)
 - [TaskSpecResources](doc\/TaskSpecResources.md)
 - [TaskSpecRestartPolicy](doc\/TaskSpecRestartPolicy.md)
 - [TaskState](doc\/TaskState.md)
 - [TaskStatus](doc\/TaskStatus.md)
 - [TaskStatusContainerStatus](doc\/TaskStatusContainerStatus.md)
 - [ThrottleDevice](doc\/ThrottleDevice.md)
 - [UnlockKeyResponse](doc\/UnlockKeyResponse.md)
 - [Volume](doc\/Volume.md)
 - [VolumeConfig](doc\/VolumeConfig.md)
 - [VolumeListResponse](doc\/VolumeListResponse.md)
 - [VolumePruneResponse](doc\/VolumePruneResponse.md)
 - [VolumeUsageData](doc\/VolumeUsageData.md)


## Documentation For Authorization

 All endpoints do not require authorization.


## Author




