# openapi.api.ImageApi

## Load the API package
```dart
import 'package:docker_client/api.dart';
```

All URIs are relative to *http://localhost/v1.40*

Method | HTTP request | Description
------------- | ------------- | -------------
[**buildPrune**](ImageApi.md#buildPrune) | **POST** /build/prune | Delete builder cache
[**imageBuild**](ImageApi.md#imageBuild) | **POST** /build | Build an image
[**imageCommit**](ImageApi.md#imageCommit) | **POST** /commit | Create a new image from a container
[**imageCreate**](ImageApi.md#imageCreate) | **POST** /images/create | Create an image
[**imageDelete**](ImageApi.md#imageDelete) | **DELETE** /images/{name} | Remove an image
[**imageGet**](ImageApi.md#imageGet) | **GET** /images/{name}/get | Export an image
[**imageGetAll**](ImageApi.md#imageGetAll) | **GET** /images/get | Export several images
[**imageHistory**](ImageApi.md#imageHistory) | **GET** /images/{name}/history | Get the history of an image
[**imageInspect**](ImageApi.md#imageInspect) | **GET** /images/{name}/json | Inspect an image
[**imageList**](ImageApi.md#imageList) | **GET** /images/json | List Images
[**imageLoad**](ImageApi.md#imageLoad) | **POST** /images/load | Import images
[**imagePrune**](ImageApi.md#imagePrune) | **POST** /images/prune | Delete unused images
[**imagePush**](ImageApi.md#imagePush) | **POST** /images/{name}/push | Push an image
[**imageSearch**](ImageApi.md#imageSearch) | **GET** /images/search | Search images
[**imageTag**](ImageApi.md#imageTag) | **POST** /images/{name}/tag | Tag an image


# **buildPrune**
> BuildPruneResponse buildPrune(keepStorage, all, filters)

Delete builder cache

### Example 
```dart
import 'package:docker_client/api.dart';

var api_instance = ImageApi();
var keepStorage = 789; // int | Amount of disk space in bytes to keep for cache
var all = true; // bool | Remove all types of build cache
var filters = filters_example; // String | A JSON encoded value of the filters (a `map[string][]string`) to process on the list of build cache objects.  Available filters:  - `until=<duration>`: duration relative to daemon's time, during which build cache was not used, in Go's duration format (e.g., '24h') - `id=<id>` - `parent=<id>` - `type=<string>` - `description=<string>` - `inuse` - `shared` - `private` 

try { 
    var result = api_instance.buildPrune(keepStorage, all, filters);
    print(result);
} catch (e) {
    print("Exception when calling ImageApi->buildPrune: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **keepStorage** | **int**| Amount of disk space in bytes to keep for cache | [optional] [default to null]
 **all** | **bool**| Remove all types of build cache | [optional] [default to null]
 **filters** | **String**| A JSON encoded value of the filters (a &#x60;map[string][]string&#x60;) to process on the list of build cache objects.  Available filters:  - &#x60;until&#x3D;&lt;duration&gt;&#x60;: duration relative to daemon&#39;s time, during which build cache was not used, in Go&#39;s duration format (e.g., &#39;24h&#39;) - &#x60;id&#x3D;&lt;id&gt;&#x60; - &#x60;parent&#x3D;&lt;id&gt;&#x60; - &#x60;type&#x3D;&lt;string&gt;&#x60; - &#x60;description&#x3D;&lt;string&gt;&#x60; - &#x60;inuse&#x60; - &#x60;shared&#x60; - &#x60;private&#x60;  | [optional] [default to null]

### Return type

[**BuildPruneResponse**](BuildPruneResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **imageBuild**
> imageBuild(dockerfile, t, extrahosts, remote, q, nocache, cachefrom, pull, rm, forcerm, memory, memswap, cpushares, cpusetcpus, cpuperiod, cpuquota, buildargs, shmsize, squash, labels, networkmode, contentType, xRegistryConfig, platform, target, outputs, inputStream)

Build an image

Build an image from a tar archive with a `Dockerfile` in it.  The `Dockerfile` specifies how the image is built from the tar archive. It is typically in the archive's root, but can be at a different path or have a different name by specifying the `dockerfile` parameter. [See the `Dockerfile` reference for more information](https://docs.docker.com/engine/reference/builder/).  The Docker daemon performs a preliminary validation of the `Dockerfile` before starting the build, and returns an error if the syntax is incorrect. After that, each instruction is run one-by-one until the ID of the new image is output.  The build is canceled if the client drops the connection by quitting or being killed. 

### Example 
```dart
import 'package:docker_client/api.dart';

var api_instance = ImageApi();
var dockerfile = dockerfile_example; // String | Path within the build context to the `Dockerfile`. This is ignored if `remote` is specified and points to an external `Dockerfile`.
var t = t_example; // String | A name and optional tag to apply to the image in the `name:tag` format. If you omit the tag the default `latest` value is assumed. You can provide several `t` parameters.
var extrahosts = extrahosts_example; // String | Extra hosts to add to /etc/hosts
var remote = remote_example; // String | A Git repository URI or HTTP/HTTPS context URI. If the URI points to a single text file, the file’s contents are placed into a file called `Dockerfile` and the image is built from that file. If the URI points to a tarball, the file is downloaded by the daemon and the contents therein used as the context for the build. If the URI points to a tarball and the `dockerfile` parameter is also specified, there must be a file with the corresponding path inside the tarball.
var q = true; // bool | Suppress verbose build output.
var nocache = true; // bool | Do not use the cache when building the image.
var cachefrom = cachefrom_example; // String | JSON array of images used for build cache resolution.
var pull = pull_example; // String | Attempt to pull the image even if an older image exists locally.
var rm = true; // bool | Remove intermediate containers after a successful build.
var forcerm = true; // bool | Always remove intermediate containers, even upon failure.
var memory = 56; // int | Set memory limit for build.
var memswap = 56; // int | Total memory (memory + swap). Set as `-1` to disable swap.
var cpushares = 56; // int | CPU shares (relative weight).
var cpusetcpus = cpusetcpus_example; // String | CPUs in which to allow execution (e.g., `0-3`, `0,1`).
var cpuperiod = 56; // int | The length of a CPU period in microseconds.
var cpuquota = 56; // int | Microseconds of CPU time that the container can get in a CPU period.
var buildargs = buildargs_example; // String | JSON map of string pairs for build-time variables. Users pass these values at build-time. Docker uses the buildargs as the environment context for commands run via the `Dockerfile` RUN instruction, or for variable expansion in other `Dockerfile` instructions. This is not meant for passing secret values.  For example, the build arg `FOO=bar` would become `{\"FOO\":\"bar\"}` in JSON. This would result in the the query parameter `buildargs={\"FOO\":\"bar\"}`. Note that `{\"FOO\":\"bar\"}` should be URI component encoded.  [Read more about the buildargs instruction.](https://docs.docker.com/engine/reference/builder/#arg) 
var shmsize = 56; // int | Size of `/dev/shm` in bytes. The size must be greater than 0. If omitted the system uses 64MB.
var squash = true; // bool | Squash the resulting images layers into a single layer. *(Experimental release only.)*
var labels = labels_example; // String | Arbitrary key/value labels to set on the image, as a JSON map of string pairs.
var networkmode = networkmode_example; // String | Sets the networking mode for the run commands during build. Supported standard values are: `bridge`, `host`, `none`, and `container:<name|id>`. Any other value is taken as a custom network's name or ID to which this container should connect to. 
var contentType = contentType_example; // String | 
var xRegistryConfig = xRegistryConfig_example; // String | This is a base64-encoded JSON object with auth configurations for multiple registries that a build may refer to.  The key is a registry URL, and the value is an auth configuration object, [as described in the authentication section](#section/Authentication). For example:  ``` {   \"docker.example.com\": {     \"username\": \"janedoe\",     \"password\": \"hunter2\"   },   \"https://index.docker.io/v1/\": {     \"username\": \"mobydock\",     \"password\": \"conta1n3rize14\"   } } ```  Only the registry domain name (and port if not the default 443) are required. However, for legacy reasons, the Docker Hub registry must be specified with both a `https://` prefix and a `/v1/` suffix even though Docker will prefer to use the v2 registry API. 
var platform = platform_example; // String | Platform in the format os[/arch[/variant]]
var target = target_example; // String | Target build stage
var outputs = outputs_example; // String | BuildKit output configuration
var inputStream = MultipartFile(); // MultipartFile | A tar archive compressed with one of the following algorithms: identity (no compression), gzip, bzip2, xz.

try { 
    api_instance.imageBuild(dockerfile, t, extrahosts, remote, q, nocache, cachefrom, pull, rm, forcerm, memory, memswap, cpushares, cpusetcpus, cpuperiod, cpuquota, buildargs, shmsize, squash, labels, networkmode, contentType, xRegistryConfig, platform, target, outputs, inputStream);
} catch (e) {
    print("Exception when calling ImageApi->imageBuild: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **dockerfile** | **String**| Path within the build context to the &#x60;Dockerfile&#x60;. This is ignored if &#x60;remote&#x60; is specified and points to an external &#x60;Dockerfile&#x60;. | [optional] [default to &quot;Dockerfile&quot;]
 **t** | **String**| A name and optional tag to apply to the image in the &#x60;name:tag&#x60; format. If you omit the tag the default &#x60;latest&#x60; value is assumed. You can provide several &#x60;t&#x60; parameters. | [optional] [default to null]
 **extrahosts** | **String**| Extra hosts to add to /etc/hosts | [optional] [default to null]
 **remote** | **String**| A Git repository URI or HTTP/HTTPS context URI. If the URI points to a single text file, the file’s contents are placed into a file called &#x60;Dockerfile&#x60; and the image is built from that file. If the URI points to a tarball, the file is downloaded by the daemon and the contents therein used as the context for the build. If the URI points to a tarball and the &#x60;dockerfile&#x60; parameter is also specified, there must be a file with the corresponding path inside the tarball. | [optional] [default to null]
 **q** | **bool**| Suppress verbose build output. | [optional] [default to false]
 **nocache** | **bool**| Do not use the cache when building the image. | [optional] [default to false]
 **cachefrom** | **String**| JSON array of images used for build cache resolution. | [optional] [default to null]
 **pull** | **String**| Attempt to pull the image even if an older image exists locally. | [optional] [default to null]
 **rm** | **bool**| Remove intermediate containers after a successful build. | [optional] [default to true]
 **forcerm** | **bool**| Always remove intermediate containers, even upon failure. | [optional] [default to false]
 **memory** | **int**| Set memory limit for build. | [optional] [default to null]
 **memswap** | **int**| Total memory (memory + swap). Set as &#x60;-1&#x60; to disable swap. | [optional] [default to null]
 **cpushares** | **int**| CPU shares (relative weight). | [optional] [default to null]
 **cpusetcpus** | **String**| CPUs in which to allow execution (e.g., &#x60;0-3&#x60;, &#x60;0,1&#x60;). | [optional] [default to null]
 **cpuperiod** | **int**| The length of a CPU period in microseconds. | [optional] [default to null]
 **cpuquota** | **int**| Microseconds of CPU time that the container can get in a CPU period. | [optional] [default to null]
 **buildargs** | **String**| JSON map of string pairs for build-time variables. Users pass these values at build-time. Docker uses the buildargs as the environment context for commands run via the &#x60;Dockerfile&#x60; RUN instruction, or for variable expansion in other &#x60;Dockerfile&#x60; instructions. This is not meant for passing secret values.  For example, the build arg &#x60;FOO&#x3D;bar&#x60; would become &#x60;{\&quot;FOO\&quot;:\&quot;bar\&quot;}&#x60; in JSON. This would result in the the query parameter &#x60;buildargs&#x3D;{\&quot;FOO\&quot;:\&quot;bar\&quot;}&#x60;. Note that &#x60;{\&quot;FOO\&quot;:\&quot;bar\&quot;}&#x60; should be URI component encoded.  [Read more about the buildargs instruction.](https://docs.docker.com/engine/reference/builder/#arg)  | [optional] [default to null]
 **shmsize** | **int**| Size of &#x60;/dev/shm&#x60; in bytes. The size must be greater than 0. If omitted the system uses 64MB. | [optional] [default to null]
 **squash** | **bool**| Squash the resulting images layers into a single layer. *(Experimental release only.)* | [optional] [default to null]
 **labels** | **String**| Arbitrary key/value labels to set on the image, as a JSON map of string pairs. | [optional] [default to null]
 **networkmode** | **String**| Sets the networking mode for the run commands during build. Supported standard values are: &#x60;bridge&#x60;, &#x60;host&#x60;, &#x60;none&#x60;, and &#x60;container:&lt;name|id&gt;&#x60;. Any other value is taken as a custom network&#39;s name or ID to which this container should connect to.  | [optional] [default to null]
 **contentType** | **String**|  | [optional] [default to &quot;application/x-tar&quot;]
 **xRegistryConfig** | **String**| This is a base64-encoded JSON object with auth configurations for multiple registries that a build may refer to.  The key is a registry URL, and the value is an auth configuration object, [as described in the authentication section](#section/Authentication). For example:  &#x60;&#x60;&#x60; {   \&quot;docker.example.com\&quot;: {     \&quot;username\&quot;: \&quot;janedoe\&quot;,     \&quot;password\&quot;: \&quot;hunter2\&quot;   },   \&quot;https://index.docker.io/v1/\&quot;: {     \&quot;username\&quot;: \&quot;mobydock\&quot;,     \&quot;password\&quot;: \&quot;conta1n3rize14\&quot;   } } &#x60;&#x60;&#x60;  Only the registry domain name (and port if not the default 443) are required. However, for legacy reasons, the Docker Hub registry must be specified with both a &#x60;https://&#x60; prefix and a &#x60;/v1/&#x60; suffix even though Docker will prefer to use the v2 registry API.  | [optional] [default to null]
 **platform** | **String**| Platform in the format os[/arch[/variant]] | [optional] [default to null]
 **target** | **String**| Target build stage | [optional] [default to null]
 **outputs** | **String**| BuildKit output configuration | [optional] [default to null]
 **inputStream** | **MultipartFile**| A tar archive compressed with one of the following algorithms: identity (no compression), gzip, bzip2, xz. | [optional] 

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/octet-stream
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **imageCommit**
> IdResponse imageCommit(container, repo, tag, comment, author, pause, changes, containerConfig)

Create a new image from a container

### Example 
```dart
import 'package:docker_client/api.dart';

var api_instance = ImageApi();
var container = container_example; // String | The ID or name of the container to commit
var repo = repo_example; // String | Repository name for the created image
var tag = tag_example; // String | Tag name for the create image
var comment = comment_example; // String | Commit message
var author = author_example; // String | Author of the image (e.g., `John Hannibal Smith <hannibal@a-team.com>`)
var pause = true; // bool | Whether to pause the container before committing
var changes = changes_example; // String | `Dockerfile` instructions to apply while committing
var containerConfig = ContainerConfig(); // ContainerConfig | The container configuration

try { 
    var result = api_instance.imageCommit(container, repo, tag, comment, author, pause, changes, containerConfig);
    print(result);
} catch (e) {
    print("Exception when calling ImageApi->imageCommit: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container** | **String**| The ID or name of the container to commit | [optional] [default to null]
 **repo** | **String**| Repository name for the created image | [optional] [default to null]
 **tag** | **String**| Tag name for the create image | [optional] [default to null]
 **comment** | **String**| Commit message | [optional] [default to null]
 **author** | **String**| Author of the image (e.g., &#x60;John Hannibal Smith &lt;hannibal@a-team.com&gt;&#x60;) | [optional] [default to null]
 **pause** | **bool**| Whether to pause the container before committing | [optional] [default to true]
 **changes** | **String**| &#x60;Dockerfile&#x60; instructions to apply while committing | [optional] [default to null]
 **containerConfig** | [**ContainerConfig**](ContainerConfig.md)| The container configuration | [optional] 

### Return type

[**IdResponse**](IdResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **imageCreate**
> imageCreate(fromImage, fromSrc, repo, tag, message, xRegistryAuth, platform, inputImage)

Create an image

Create an image by either pulling it from a registry or importing it.

### Example 
```dart
import 'package:docker_client/api.dart';

var api_instance = ImageApi();
var fromImage = fromImage_example; // String | Name of the image to pull. The name may include a tag or digest. This parameter may only be used when pulling an image. The pull is cancelled if the HTTP connection is closed.
var fromSrc = fromSrc_example; // String | Source to import. The value may be a URL from which the image can be retrieved or `-` to read the image from the request body. This parameter may only be used when importing an image.
var repo = repo_example; // String | Repository name given to an image when it is imported. The repo may include a tag. This parameter may only be used when importing an image.
var tag = tag_example; // String | Tag or digest. If empty when pulling an image, this causes all tags for the given image to be pulled.
var message = message_example; // String | Set commit message for imported image.
var xRegistryAuth = xRegistryAuth_example; // String | A base64url-encoded auth configuration.  Refer to the [authentication section](#section/Authentication) for details. 
var platform = platform_example; // String | Platform in the format os[/arch[/variant]]
var inputImage = String(); // String | Image content if the value `-` has been specified in fromSrc query parameter

try { 
    api_instance.imageCreate(fromImage, fromSrc, repo, tag, message, xRegistryAuth, platform, inputImage);
} catch (e) {
    print("Exception when calling ImageApi->imageCreate: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **fromImage** | **String**| Name of the image to pull. The name may include a tag or digest. This parameter may only be used when pulling an image. The pull is cancelled if the HTTP connection is closed. | [optional] [default to null]
 **fromSrc** | **String**| Source to import. The value may be a URL from which the image can be retrieved or &#x60;-&#x60; to read the image from the request body. This parameter may only be used when importing an image. | [optional] [default to null]
 **repo** | **String**| Repository name given to an image when it is imported. The repo may include a tag. This parameter may only be used when importing an image. | [optional] [default to null]
 **tag** | **String**| Tag or digest. If empty when pulling an image, this causes all tags for the given image to be pulled. | [optional] [default to null]
 **message** | **String**| Set commit message for imported image. | [optional] [default to null]
 **xRegistryAuth** | **String**| A base64url-encoded auth configuration.  Refer to the [authentication section](#section/Authentication) for details.  | [optional] [default to null]
 **platform** | **String**| Platform in the format os[/arch[/variant]] | [optional] [default to null]
 **inputImage** | **String**| Image content if the value &#x60;-&#x60; has been specified in fromSrc query parameter | [optional] 

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: text/plain, application/octet-stream
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **imageDelete**
> List<ImageDeleteResponseItem> imageDelete(name, force, noprune)

Remove an image

Remove an image, along with any untagged parent images that were referenced by that image.  Images can't be removed if they have descendant images, are being used by a running container or are being used by a build. 

### Example 
```dart
import 'package:docker_client/api.dart';

var api_instance = ImageApi();
var name = name_example; // String | Image name or ID
var force = true; // bool | Remove the image even if it is being used by stopped containers or has other tags
var noprune = true; // bool | Do not delete untagged parent images

try { 
    var result = api_instance.imageDelete(name, force, noprune);
    print(result);
} catch (e) {
    print("Exception when calling ImageApi->imageDelete: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **name** | **String**| Image name or ID | [default to null]
 **force** | **bool**| Remove the image even if it is being used by stopped containers or has other tags | [optional] [default to false]
 **noprune** | **bool**| Do not delete untagged parent images | [optional] [default to false]

### Return type

[**List<ImageDeleteResponseItem>**](ImageDeleteResponseItem.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **imageGet**
> MultipartFile imageGet(name)

Export an image

Get a tarball containing all images and metadata for a repository.  If `name` is a specific name and tag (e.g. `ubuntu:latest`), then only that image (and its parents) are returned. If `name` is an image ID, similarly only that image (and its parents) are returned, but with the exclusion of the `repositories` file in the tarball, as there were no image names referenced.  ### Image tarball format  An image tarball contains one directory per image layer (named using its long ID), each containing these files:  - `VERSION`: currently `1.0` - the file format version - `json`: detailed layer information, similar to `docker inspect layer_id` - `layer.tar`: A tarfile containing the filesystem changes in this layer  The `layer.tar` file contains `aufs` style `.wh..wh.aufs` files and directories for storing attribute changes and deletions.  If the tarball defines a repository, the tarball should also include a `repositories` file at the root that contains a list of repository and tag names mapped to layer IDs.  ```json {   \"hello-world\": {     \"latest\": \"565a9d68a73f6706862bfe8409a7f659776d4d60a8d096eb4a3cbce6999cc2a1\"   } } ``` 

### Example 
```dart
import 'package:docker_client/api.dart';

var api_instance = ImageApi();
var name = name_example; // String | Image name or ID

try { 
    var result = api_instance.imageGet(name);
    print(result);
} catch (e) {
    print("Exception when calling ImageApi->imageGet: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **name** | **String**| Image name or ID | [default to null]

### Return type

[**MultipartFile**](File.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-tar

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **imageGetAll**
> MultipartFile imageGetAll(names)

Export several images

Get a tarball containing all images and metadata for several image repositories.  For each value of the `names` parameter: if it is a specific name and tag (e.g. `ubuntu:latest`), then only that image (and its parents) are returned; if it is an image ID, similarly only that image (and its parents) are returned and there would be no names referenced in the 'repositories' file for this image ID.  For details on the format, see the [export image endpoint](#operation/ImageGet). 

### Example 
```dart
import 'package:docker_client/api.dart';

var api_instance = ImageApi();
var names = []; // List<String> | Image names to filter by

try { 
    var result = api_instance.imageGetAll(names);
    print(result);
} catch (e) {
    print("Exception when calling ImageApi->imageGetAll: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **names** | [**List&lt;String&gt;**](String.md)| Image names to filter by | [optional] [default to []]

### Return type

[**MultipartFile**](File.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-tar

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **imageHistory**
> List<HistoryResponseItem> imageHistory(name)

Get the history of an image

Return parent layers of an image.

### Example 
```dart
import 'package:docker_client/api.dart';

var api_instance = ImageApi();
var name = name_example; // String | Image name or ID

try { 
    var result = api_instance.imageHistory(name);
    print(result);
} catch (e) {
    print("Exception when calling ImageApi->imageHistory: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **name** | **String**| Image name or ID | [default to null]

### Return type

[**List<HistoryResponseItem>**](HistoryResponseItem.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **imageInspect**
> Image imageInspect(name)

Inspect an image

Return low-level information about an image.

### Example 
```dart
import 'package:docker_client/api.dart';

var api_instance = ImageApi();
var name = name_example; // String | Image name or id

try { 
    var result = api_instance.imageInspect(name);
    print(result);
} catch (e) {
    print("Exception when calling ImageApi->imageInspect: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **name** | **String**| Image name or id | [default to null]

### Return type

[**Image**](Image.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **imageList**
> List<ImageSummary> imageList(all, filters, digests)

List Images

Returns a list of images on the server. Note that it uses a different, smaller representation of an image than inspecting a single image.

### Example 
```dart
import 'package:docker_client/api.dart';

var api_instance = ImageApi();
var all = true; // bool | Show all images. Only images from a final layer (no children) are shown by default.
var filters = filters_example; // String | A JSON encoded value of the filters (a `map[string][]string`) to process on the images list.  Available filters:  - `before`=(`<image-name>[:<tag>]`,  `<image id>` or `<image@digest>`) - `dangling=true` - `label=key` or `label=\"key=value\"` of an image label - `reference`=(`<image-name>[:<tag>]`) - `since`=(`<image-name>[:<tag>]`,  `<image id>` or `<image@digest>`) 
var digests = true; // bool | Show digest information as a `RepoDigests` field on each image.

try { 
    var result = api_instance.imageList(all, filters, digests);
    print(result);
} catch (e) {
    print("Exception when calling ImageApi->imageList: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **all** | **bool**| Show all images. Only images from a final layer (no children) are shown by default. | [optional] [default to false]
 **filters** | **String**| A JSON encoded value of the filters (a &#x60;map[string][]string&#x60;) to process on the images list.  Available filters:  - &#x60;before&#x60;&#x3D;(&#x60;&lt;image-name&gt;[:&lt;tag&gt;]&#x60;,  &#x60;&lt;image id&gt;&#x60; or &#x60;&lt;image@digest&gt;&#x60;) - &#x60;dangling&#x3D;true&#x60; - &#x60;label&#x3D;key&#x60; or &#x60;label&#x3D;\&quot;key&#x3D;value\&quot;&#x60; of an image label - &#x60;reference&#x60;&#x3D;(&#x60;&lt;image-name&gt;[:&lt;tag&gt;]&#x60;) - &#x60;since&#x60;&#x3D;(&#x60;&lt;image-name&gt;[:&lt;tag&gt;]&#x60;,  &#x60;&lt;image id&gt;&#x60; or &#x60;&lt;image@digest&gt;&#x60;)  | [optional] [default to null]
 **digests** | **bool**| Show digest information as a &#x60;RepoDigests&#x60; field on each image. | [optional] [default to false]

### Return type

[**List<ImageSummary>**](ImageSummary.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **imageLoad**
> imageLoad(quiet, imagesTarball)

Import images

Load a set of images and tags into a repository.  For details on the format, see the [export image endpoint](#operation/ImageGet). 

### Example 
```dart
import 'package:docker_client/api.dart';

var api_instance = ImageApi();
var quiet = true; // bool | Suppress progress details during load.
var imagesTarball = MultipartFile(); // MultipartFile | Tar archive containing images

try { 
    api_instance.imageLoad(quiet, imagesTarball);
} catch (e) {
    print("Exception when calling ImageApi->imageLoad: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **quiet** | **bool**| Suppress progress details during load. | [optional] [default to false]
 **imagesTarball** | **MultipartFile**| Tar archive containing images | [optional] 

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/x-tar
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **imagePrune**
> ImagePruneResponse imagePrune(filters)

Delete unused images

### Example 
```dart
import 'package:docker_client/api.dart';

var api_instance = ImageApi();
var filters = filters_example; // String | Filters to process on the prune list, encoded as JSON (a `map[string][]string`). Available filters:  - `dangling=<boolean>` When set to `true` (or `1`), prune only    unused *and* untagged images. When set to `false`    (or `0`), all unused images are pruned. - `until=<string>` Prune images created before this timestamp. The `<timestamp>` can be Unix timestamps, date formatted timestamps, or Go duration strings (e.g. `10m`, `1h30m`) computed relative to the daemon machine’s time. - `label` (`label=<key>`, `label=<key>=<value>`, `label!=<key>`, or `label!=<key>=<value>`) Prune images with (or without, in case `label!=...` is used) the specified labels. 

try { 
    var result = api_instance.imagePrune(filters);
    print(result);
} catch (e) {
    print("Exception when calling ImageApi->imagePrune: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **filters** | **String**| Filters to process on the prune list, encoded as JSON (a &#x60;map[string][]string&#x60;). Available filters:  - &#x60;dangling&#x3D;&lt;boolean&gt;&#x60; When set to &#x60;true&#x60; (or &#x60;1&#x60;), prune only    unused *and* untagged images. When set to &#x60;false&#x60;    (or &#x60;0&#x60;), all unused images are pruned. - &#x60;until&#x3D;&lt;string&gt;&#x60; Prune images created before this timestamp. The &#x60;&lt;timestamp&gt;&#x60; can be Unix timestamps, date formatted timestamps, or Go duration strings (e.g. &#x60;10m&#x60;, &#x60;1h30m&#x60;) computed relative to the daemon machine’s time. - &#x60;label&#x60; (&#x60;label&#x3D;&lt;key&gt;&#x60;, &#x60;label&#x3D;&lt;key&gt;&#x3D;&lt;value&gt;&#x60;, &#x60;label!&#x3D;&lt;key&gt;&#x60;, or &#x60;label!&#x3D;&lt;key&gt;&#x3D;&lt;value&gt;&#x60;) Prune images with (or without, in case &#x60;label!&#x3D;...&#x60; is used) the specified labels.  | [optional] [default to null]

### Return type

[**ImagePruneResponse**](ImagePruneResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **imagePush**
> imagePush(name, xRegistryAuth, tag)

Push an image

Push an image to a registry.  If you wish to push an image on to a private registry, that image must already have a tag which references the registry. For example, `registry.example.com/myimage:latest`.  The push is cancelled if the HTTP connection is closed. 

### Example 
```dart
import 'package:docker_client/api.dart';

var api_instance = ImageApi();
var name = name_example; // String | Image name or ID.
var xRegistryAuth = xRegistryAuth_example; // String | A base64url-encoded auth configuration.  Refer to the [authentication section](#section/Authentication) for details. 
var tag = tag_example; // String | The tag to associate with the image on the registry.

try { 
    api_instance.imagePush(name, xRegistryAuth, tag);
} catch (e) {
    print("Exception when calling ImageApi->imagePush: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **name** | **String**| Image name or ID. | [default to null]
 **xRegistryAuth** | **String**| A base64url-encoded auth configuration.  Refer to the [authentication section](#section/Authentication) for details.  | [default to null]
 **tag** | **String**| The tag to associate with the image on the registry. | [optional] [default to null]

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json, text/plain

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **imageSearch**
> List<ImageSearchResponseItem> imageSearch(term, limit, filters)

Search images

Search for an image on Docker Hub.

### Example 
```dart
import 'package:docker_client/api.dart';

var api_instance = ImageApi();
var term = term_example; // String | Term to search
var limit = 56; // int | Maximum number of results to return
var filters = filters_example; // String | A JSON encoded value of the filters (a `map[string][]string`) to process on the images list. Available filters:  - `is-automated=(true|false)` - `is-official=(true|false)` - `stars=<number>` Matches images that has at least 'number' stars. 

try { 
    var result = api_instance.imageSearch(term, limit, filters);
    print(result);
} catch (e) {
    print("Exception when calling ImageApi->imageSearch: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **term** | **String**| Term to search | [default to null]
 **limit** | **int**| Maximum number of results to return | [optional] [default to null]
 **filters** | **String**| A JSON encoded value of the filters (a &#x60;map[string][]string&#x60;) to process on the images list. Available filters:  - &#x60;is-automated&#x3D;(true|false)&#x60; - &#x60;is-official&#x3D;(true|false)&#x60; - &#x60;stars&#x3D;&lt;number&gt;&#x60; Matches images that has at least &#39;number&#39; stars.  | [optional] [default to null]

### Return type

[**List<ImageSearchResponseItem>**](ImageSearchResponseItem.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **imageTag**
> imageTag(name, repo, tag)

Tag an image

Tag an image so that it becomes part of a repository.

### Example 
```dart
import 'package:docker_client/api.dart';

var api_instance = ImageApi();
var name = name_example; // String | Image name or ID to tag.
var repo = repo_example; // String | The repository to tag in. For example, `someuser/someimage`.
var tag = tag_example; // String | The name of the new tag.

try { 
    api_instance.imageTag(name, repo, tag);
} catch (e) {
    print("Exception when calling ImageApi->imageTag: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **name** | **String**| Image name or ID to tag. | [default to null]
 **repo** | **String**| The repository to tag in. For example, &#x60;someuser/someimage&#x60;. | [optional] [default to null]
 **tag** | **String**| The name of the new tag. | [optional] [default to null]

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json, text/plain

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

