# openapi.model.SystemInfo

## Load the model package
```dart
import 'package:docker_client/api.dart';
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**ID** | **String** | Unique identifier of the daemon.  &lt;p&gt;&lt;br /&gt;&lt;/p&gt;  &gt; **Note**: The format of the ID itself is not part of the API, and &gt; should not be considered stable.  | [optional] [default to null]
**containers** | **int** | Total number of containers on the host. | [optional] [default to null]
**containersRunning** | **int** | Number of containers with status &#x60;\&quot;running\&quot;&#x60;.  | [optional] [default to null]
**containersPaused** | **int** | Number of containers with status &#x60;\&quot;paused\&quot;&#x60;.  | [optional] [default to null]
**containersStopped** | **int** | Number of containers with status &#x60;\&quot;stopped\&quot;&#x60;.  | [optional] [default to null]
**images** | **int** | Total number of images on the host.  Both _tagged_ and _untagged_ (dangling) images are counted.  | [optional] [default to null]
**driver** | **String** | Name of the storage driver in use. | [optional] [default to null]
**driverStatus** | [**List&lt;List&lt;String&gt;&gt;**](List.md) | Information specific to the storage driver, provided as \&quot;label\&quot; / \&quot;value\&quot; pairs.  This information is provided by the storage driver, and formatted in a way consistent with the output of &#x60;docker info&#x60; on the command line.  &lt;p&gt;&lt;br /&gt;&lt;/p&gt;  &gt; **Note**: The information returned in this field, including the &gt; formatting of values and labels, should not be considered stable, &gt; and may change without notice.  | [optional] [default to []]
**dockerRootDir** | **String** | Root directory of persistent Docker state.  Defaults to &#x60;/var/lib/docker&#x60; on Linux, and &#x60;C:\\ProgramData\\docker&#x60; on Windows.  | [optional] [default to null]
**systemStatus** | [**List&lt;List&lt;String&gt;&gt;**](List.md) | Status information about this node (standalone Swarm API).  &lt;p&gt;&lt;br /&gt;&lt;/p&gt;  &gt; **Note**: The information returned in this field is only propagated &gt; by the Swarm standalone API, and is empty (&#x60;null&#x60;) when using &gt; built-in swarm mode.  | [optional] [default to []]
**plugins** | [**PluginsInfo**](PluginsInfo.md) |  | [optional] [default to null]
**memoryLimit** | **bool** | Indicates if the host has memory limit support enabled. | [optional] [default to null]
**swapLimit** | **bool** | Indicates if the host has memory swap limit support enabled. | [optional] [default to null]
**kernelMemory** | **bool** | Indicates if the host has kernel memory limit support enabled. | [optional] [default to null]
**cpuCfsPeriod** | **bool** | Indicates if CPU CFS(Completely Fair Scheduler) period is supported by the host.  | [optional] [default to null]
**cpuCfsQuota** | **bool** | Indicates if CPU CFS(Completely Fair Scheduler) quota is supported by the host.  | [optional] [default to null]
**cPUShares** | **bool** | Indicates if CPU Shares limiting is supported by the host.  | [optional] [default to null]
**cPUSet** | **bool** | Indicates if CPUsets (cpuset.cpus, cpuset.mems) are supported by the host.  See [cpuset(7)](https://www.kernel.org/doc/Documentation/cgroup-v1/cpusets.txt)  | [optional] [default to null]
**pidsLimit** | **bool** | Indicates if the host kernel has PID limit support enabled. | [optional] [default to null]
**oomKillDisable** | **bool** | Indicates if OOM killer disable is supported on the host. | [optional] [default to null]
**iPv4Forwarding** | **bool** | Indicates IPv4 forwarding is enabled. | [optional] [default to null]
**bridgeNfIptables** | **bool** | Indicates if &#x60;bridge-nf-call-iptables&#x60; is available on the host. | [optional] [default to null]
**bridgeNfIp6tables** | **bool** | Indicates if &#x60;bridge-nf-call-ip6tables&#x60; is available on the host. | [optional] [default to null]
**debug** | **bool** | Indicates if the daemon is running in debug-mode / with debug-level logging enabled.  | [optional] [default to null]
**nFd** | **int** | The total number of file Descriptors in use by the daemon process.  This information is only returned if debug-mode is enabled.  | [optional] [default to null]
**nGoroutines** | **int** | The  number of goroutines that currently exist.  This information is only returned if debug-mode is enabled.  | [optional] [default to null]
**systemTime** | **String** | Current system-time in [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.  | [optional] [default to null]
**loggingDriver** | **String** | The logging driver to use as a default for new containers.  | [optional] [default to null]
**cgroupDriver** | **String** | The driver to use for managing cgroups.  | [optional] [default to &quot;cgroupfs&quot;]
**nEventsListener** | **int** | Number of event listeners subscribed. | [optional] [default to null]
**kernelVersion** | **String** | Kernel version of the host.  On Linux, this information obtained from &#x60;uname&#x60;. On Windows this information is queried from the &lt;kbd&gt;HKEY_LOCAL_MACHINE\\\\SOFTWARE\\\\Microsoft\\\\Windows NT\\\\CurrentVersion\\\\&lt;/kbd&gt; registry value, for example _\&quot;10.0 14393 (14393.1198.amd64fre.rs1_release_sec.170427-1353)\&quot;_.  | [optional] [default to null]
**operatingSystem** | **String** | Name of the host&#39;s operating system, for example: \&quot;Ubuntu 16.04.2 LTS\&quot; or \&quot;Windows Server 2016 Datacenter\&quot;  | [optional] [default to null]
**oSType** | **String** | Generic type of the operating system of the host, as returned by the Go runtime (&#x60;GOOS&#x60;).  Currently returned values are \&quot;linux\&quot; and \&quot;windows\&quot;. A full list of possible values can be found in the [Go documentation](https://golang.org/doc/install/source#environment).  | [optional] [default to null]
**architecture** | **String** | Hardware architecture of the host, as returned by the Go runtime (&#x60;GOARCH&#x60;).  A full list of possible values can be found in the [Go documentation](https://golang.org/doc/install/source#environment).  | [optional] [default to null]
**NCPU** | **int** | The number of logical CPUs usable by the daemon.  The number of available CPUs is checked by querying the operating system when the daemon starts. Changes to operating system CPU allocation after the daemon is started are not reflected.  | [optional] [default to null]
**memTotal** | **int** | Total amount of physical memory available on the host, in bytes.  | [optional] [default to null]
**indexServerAddress** | **String** | Address / URL of the index server that is used for image search, and as a default for user authentication for Docker Hub and Docker Cloud.  | [optional] [default to &quot;https://index.docker.io/v1/&quot;]
**registryConfig** | [**RegistryServiceConfig**](RegistryServiceConfig.md) |  | [optional] [default to null]
**genericResources** | [**List&lt;Object&gt;**](Object.md) | User-defined resources can be either Integer resources (e.g, &#x60;SSD&#x3D;3&#x60;) or String resources (e.g, &#x60;GPU&#x3D;UUID1&#x60;).  | [optional] [default to []]
**httpProxy** | **String** | HTTP-proxy configured for the daemon. This value is obtained from the [&#x60;HTTP_PROXY&#x60;](https://www.gnu.org/software/wget/manual/html_node/Proxies.html) environment variable. Credentials ([user info component](https://tools.ietf.org/html/rfc3986#section-3.2.1)) in the proxy URL are masked in the API response.  Containers do not automatically inherit this configuration.  | [optional] [default to null]
**httpsProxy** | **String** | HTTPS-proxy configured for the daemon. This value is obtained from the [&#x60;HTTPS_PROXY&#x60;](https://www.gnu.org/software/wget/manual/html_node/Proxies.html) environment variable. Credentials ([user info component](https://tools.ietf.org/html/rfc3986#section-3.2.1)) in the proxy URL are masked in the API response.  Containers do not automatically inherit this configuration.  | [optional] [default to null]
**noProxy** | **String** | Comma-separated list of domain extensions for which no proxy should be used. This value is obtained from the [&#x60;NO_PROXY&#x60;](https://www.gnu.org/software/wget/manual/html_node/Proxies.html) environment variable.  Containers do not automatically inherit this configuration.  | [optional] [default to null]
**name** | **String** | Hostname of the host. | [optional] [default to null]
**labels** | **List&lt;String&gt;** | User-defined labels (key/value metadata) as set on the daemon.  &lt;p&gt;&lt;br /&gt;&lt;/p&gt;  &gt; **Note**: When part of a Swarm, nodes can both have _daemon_ labels, &gt; set through the daemon configuration, and _node_ labels, set from a &gt; manager node in the Swarm. Node labels are not included in this &gt; field. Node labels can be retrieved using the &#x60;/nodes/(id)&#x60; endpoint &gt; on a manager node in the Swarm.  | [optional] [default to []]
**experimentalBuild** | **bool** | Indicates if experimental features are enabled on the daemon.  | [optional] [default to null]
**serverVersion** | **String** | Version string of the daemon.  &gt; **Note**: the [standalone Swarm API](https://docs.docker.com/swarm/swarm-api/) &gt; returns the Swarm version instead of the daemon  version, for example &gt; &#x60;swarm/1.2.8&#x60;.  | [optional] [default to null]
**clusterStore** | **String** | URL of the distributed storage backend.   The storage backend is used for multihost networking (to store network and endpoint information) and by the node discovery mechanism.  &lt;p&gt;&lt;br /&gt;&lt;/p&gt;  &gt; **Note**: This field is only propagated when using standalone Swarm &gt; mode, and overlay networking using an external k/v store. Overlay &gt; networks with Swarm mode enabled use the built-in raft store, and &gt; this field will be empty.  | [optional] [default to null]
**clusterAdvertise** | **String** | The network endpoint that the Engine advertises for the purpose of node discovery. ClusterAdvertise is a &#x60;host:port&#x60; combination on which the daemon is reachable by other hosts.  &lt;p&gt;&lt;br /&gt;&lt;/p&gt;  &gt; **Note**: This field is only propagated when using standalone Swarm &gt; mode, and overlay networking using an external k/v store. Overlay &gt; networks with Swarm mode enabled use the built-in raft store, and &gt; this field will be empty.  | [optional] [default to null]
**runtimes** | [**Map&lt;String, Runtime&gt;**](Runtime.md) | List of [OCI compliant](https://github.com/opencontainers/runtime-spec) runtimes configured on the daemon. Keys hold the \&quot;name\&quot; used to reference the runtime.  The Docker daemon relies on an OCI compliant runtime (invoked via the &#x60;containerd&#x60; daemon) as its interface to the Linux kernel namespaces, cgroups, and SELinux.  The default runtime is &#x60;runc&#x60;, and automatically configured. Additional runtimes can be configured by the user and will be listed here.  | [optional] [default to {}]
**defaultRuntime** | **String** | Name of the default OCI runtime that is used when starting containers.  The default can be overridden per-container at create time.  | [optional] [default to &quot;runc&quot;]
**swarm** | [**SwarmInfo**](SwarmInfo.md) |  | [optional] [default to null]
**liveRestoreEnabled** | **bool** | Indicates if live restore is enabled.  If enabled, containers are kept running when the daemon is shutdown or upon daemon start if running containers are detected.  | [optional] [default to false]
**isolation** | **String** | Represents the isolation technology to use as a default for containers. The supported values are platform-specific.  If no isolation value is specified on daemon start, on Windows client, the default is &#x60;hyperv&#x60;, and on Windows server, the default is &#x60;process&#x60;.  This option is currently not used on other platforms.  | [optional] [default to &quot;default&quot;]
**initBinary** | **String** | Name and, optional, path of the &#x60;docker-init&#x60; binary.  If the path is omitted, the daemon searches the host&#39;s &#x60;$PATH&#x60; for the binary and uses the first result.  | [optional] [default to null]
**containerdCommit** | [**Commit**](Commit.md) |  | [optional] [default to null]
**runcCommit** | [**Commit**](Commit.md) |  | [optional] [default to null]
**initCommit** | [**Commit**](Commit.md) |  | [optional] [default to null]
**securityOptions** | **List&lt;String&gt;** | List of security features that are enabled on the daemon, such as apparmor, seccomp, SELinux, user-namespaces (userns), and rootless.  Additional configuration options for each security feature may be present, and are included as a comma-separated list of key/value pairs.  | [optional] [default to []]
**productLicense** | **String** | Reports a summary of the product license on the daemon.  If a commercial license has been applied to the daemon, information such as number of nodes, and expiration are included.  | [optional] [default to null]
**warnings** | **List&lt;String&gt;** | List of warnings / informational messages about missing features, or issues related to the daemon configuration.  These messages can be printed by the client as information to the user.  | [optional] [default to []]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


