library docker_client.api;

import 'dart:async';
import 'dart:convert';
import 'package:http/http.dart';

part 'api_client.dart';
part 'api_helper.dart';
part 'api_exception.dart';
part 'auth/authentication.dart';
part 'auth/api_key_auth.dart';
part 'auth/oauth.dart';
part 'auth/http_basic_auth.dart';
part 'auth/http_bearer_auth.dart';

part 'api/config_api.dart';
part 'api/container_api.dart';
part 'api/distribution_api.dart';
part 'api/exec_api.dart';
part 'api/image_api.dart';
part 'api/network_api.dart';
part 'api/node_api.dart';
part 'api/plugin_api.dart';
part 'api/secret_api.dart';
part 'api/service_api.dart';
part 'api/session_api.dart';
part 'api/swarm_api.dart';
part 'api/system_api.dart';
part 'api/task_api.dart';
part 'api/volume_api.dart';

part 'model/address.dart';
part 'model/auth_config.dart';
part 'model/build_cache.dart';
part 'model/build_info.dart';
part 'model/build_prune_response.dart';
part 'model/cluster_info.dart';
part 'model/commit.dart';
part 'model/config.dart';
part 'model/config_spec.dart';
part 'model/container_change_response_item.dart';
part 'model/container_config.dart';
part 'model/container_create_response.dart';
part 'model/container_inspect_response.dart';
part 'model/container_prune_response.dart';
part 'model/container_state.dart';
part 'model/container_summary.dart';
part 'model/container_top_response.dart';
part 'model/container_update_response.dart';
part 'model/container_wait_response.dart';
part 'model/container_wait_response_error.dart';
part 'model/create_image_info.dart';
part 'model/device_mapping.dart';
part 'model/device_request.dart';
part 'model/distribution_inspect_response.dart';
part 'model/distribution_inspect_response_descriptor.dart';
part 'model/distribution_inspect_response_platforms.dart';
part 'model/driver.dart';
part 'model/endpoint_ipam_config.dart';
part 'model/endpoint_port_config.dart';
part 'model/endpoint_settings.dart';
part 'model/endpoint_spec.dart';
part 'model/engine_description.dart';
part 'model/engine_description_plugins.dart';
part 'model/error_detail.dart';
part 'model/error_response.dart';
part 'model/exec_inspect_response.dart';
part 'model/graph_driver_data.dart';
part 'model/health.dart';
part 'model/health_config.dart';
part 'model/healthcheck_result.dart';
part 'model/history_response_item.dart';
part 'model/host_config.dart';
part 'model/host_config_all_of.dart';
part 'model/host_config_all_of_log_config.dart';
part 'model/ipam.dart';
part 'model/id_response.dart';
part 'model/image.dart';
part 'model/image_delete_response_item.dart';
part 'model/image_id.dart';
part 'model/image_metadata.dart';
part 'model/image_prune_response.dart';
part 'model/image_root_fs.dart';
part 'model/image_search_response_item.dart';
part 'model/image_summary.dart';
part 'model/index_info.dart';
part 'model/inline_object.dart';
part 'model/inline_object1.dart';
part 'model/inline_object2.dart';
part 'model/inline_object3.dart';
part 'model/inline_object4.dart';
part 'model/inline_object5.dart';
part 'model/inline_object6.dart';
part 'model/inline_object7.dart';
part 'model/inline_response400.dart';
part 'model/join_tokens.dart';
part 'model/local_node_state.dart';
part 'model/manager_status.dart';
part 'model/mount.dart';
part 'model/mount_bind_options.dart';
part 'model/mount_point.dart';
part 'model/mount_tmpfs_options.dart';
part 'model/mount_volume_options.dart';
part 'model/mount_volume_options_driver_config.dart';
part 'model/network.dart';
part 'model/network_attachment_config.dart';
part 'model/network_container.dart';
part 'model/network_create_response.dart';
part 'model/network_prune_response.dart';
part 'model/network_settings.dart';
part 'model/networking_config.dart';
part 'model/node.dart';
part 'model/node_description.dart';
part 'model/node_spec.dart';
part 'model/node_state.dart';
part 'model/node_status.dart';
part 'model/object_version.dart';
part 'model/peer_node.dart';
part 'model/platform.dart';
part 'model/plugin.dart';
part 'model/plugin_config.dart';
part 'model/plugin_config_args.dart';
part 'model/plugin_config_interface.dart';
part 'model/plugin_config_linux.dart';
part 'model/plugin_config_network.dart';
part 'model/plugin_config_rootfs.dart';
part 'model/plugin_config_user.dart';
part 'model/plugin_device.dart';
part 'model/plugin_env.dart';
part 'model/plugin_interface_type.dart';
part 'model/plugin_mount.dart';
part 'model/plugin_privilege_item.dart';
part 'model/plugin_settings.dart';
part 'model/plugins_info.dart';
part 'model/port.dart';
part 'model/port_binding.dart';
part 'model/process_config.dart';
part 'model/progress_detail.dart';
part 'model/push_image_info.dart';
part 'model/reachability.dart';
part 'model/registry_service_config.dart';
part 'model/resource_object.dart';
part 'model/resources.dart';
part 'model/resources_blkio_weight_device.dart';
part 'model/resources_ulimits.dart';
part 'model/restart_policy.dart';
part 'model/runtime.dart';
part 'model/secret.dart';
part 'model/secret_spec.dart';
part 'model/service.dart';
part 'model/service_create_response.dart';
part 'model/service_endpoint.dart';
part 'model/service_endpoint_virtual_i_ps.dart';
part 'model/service_spec.dart';
part 'model/service_spec_mode.dart';
part 'model/service_spec_mode_replicated.dart';
part 'model/service_spec_rollback_config.dart';
part 'model/service_spec_update_config.dart';
part 'model/service_update_response.dart';
part 'model/service_update_status.dart';
part 'model/swarm.dart';
part 'model/swarm_all_of.dart';
part 'model/swarm_info.dart';
part 'model/swarm_spec.dart';
part 'model/swarm_spec_ca_config.dart';
part 'model/swarm_spec_ca_config_external_c_as.dart';
part 'model/swarm_spec_dispatcher.dart';
part 'model/swarm_spec_encryption_config.dart';
part 'model/swarm_spec_orchestration.dart';
part 'model/swarm_spec_raft.dart';
part 'model/swarm_spec_task_defaults.dart';
part 'model/swarm_spec_task_defaults_log_driver.dart';
part 'model/system_auth_response.dart';
part 'model/system_data_usage_response.dart';
part 'model/system_events_response.dart';
part 'model/system_events_response_actor.dart';
part 'model/system_info.dart';
part 'model/system_version.dart';
part 'model/system_version_components.dart';
part 'model/system_version_platform.dart';
part 'model/tls_info.dart';
part 'model/task.dart';
part 'model/task_spec.dart';
part 'model/task_spec_container_spec.dart';
part 'model/task_spec_container_spec_configs.dart';
part 'model/task_spec_container_spec_dns_config.dart';
part 'model/task_spec_container_spec_file.dart';
part 'model/task_spec_container_spec_file1.dart';
part 'model/task_spec_container_spec_privileges.dart';
part 'model/task_spec_container_spec_privileges_credential_spec.dart';
part 'model/task_spec_container_spec_privileges_se_linux_context.dart';
part 'model/task_spec_container_spec_secrets.dart';
part 'model/task_spec_log_driver.dart';
part 'model/task_spec_network_attachment_spec.dart';
part 'model/task_spec_placement.dart';
part 'model/task_spec_placement_preferences.dart';
part 'model/task_spec_placement_spread.dart';
part 'model/task_spec_plugin_spec.dart';
part 'model/task_spec_resources.dart';
part 'model/task_spec_restart_policy.dart';
part 'model/task_state.dart';
part 'model/task_status.dart';
part 'model/task_status_container_status.dart';
part 'model/throttle_device.dart';
part 'model/unlock_key_response.dart';
part 'model/volume.dart';
part 'model/volume_config.dart';
part 'model/volume_list_response.dart';
part 'model/volume_prune_response.dart';
part 'model/volume_usage_data.dart';


ApiClient defaultApiClient = ApiClient();
